package com.ruoyi.interfaces.mapper;

import com.ruoyi.interfaces.domain.PtDataExp;
import com.ruoyi.interfaces.domain.PtDataExpField;

import java.util.List;

public interface PtDataExpMapper {
    int insert(PtDataExp p);

    int update(PtDataExp p);

    int delete(String id);

    List<PtDataExp> selectAll(PtDataExp p);

    PtDataExp findByOne(String id);

    int insertPtDataExpField(PtDataExpField p);

    int updatePtDataExpField(PtDataExpField p);

    List<PtDataExpField> selectAllPtDataExpField(PtDataExpField p);

    int deletePtDataExpField(PtDataExpField p);

}
